
Cryptographic modules should operate in their approved mode according to their published security policies
-------

**Description:**

Whenever cryptographic modules do not operate in their approved mode according to their 
published security policies these methods could become weak and become inadequate to 
ensure strong cyphers.


**Solution:**

Always verify that cryptographic modules operate in their approved mode according to 
their published security policies before implementing them into your application.

	